helga-dubstep
=============

A match plugin that will respond with vaiable length 'wubwubwub' when someone mentions the word 'dubstep'.


License
-------

Copyright (c) 2015 Shaun Duncan

Licensed under an `MIT`_ license.

.. _`MIT`: https://github.com/shaunduncan/helga-dubstep/blob/master/LICENSE
